==> gatsby-plugin-typescript-1.4.7.tgz: package/gatsby-node.js <==
"use strict";

var _require = require(`typescript`),
    transpileModule = _require.transpileModule;

var path = require(`path`);

var test = /\.tsx?$/;
var compilerDefaults = {
  target: `esnext`,
  experimentalDecorators: true,
  jsx: `react`
};

module.exports.resolvableExtensions = function () {
  return [`.ts`, `.tsx`];
};

module.exports.modifyWebpackConfig = function (_ref, _ref2) {
  var config = _ref.config;
  var compilerOptions = _ref2.compilerOptions;

  // CommonJS to keep Webpack happy.
  var copts = Object.assign({}, compilerDefaults, compilerOptions, {
    module: `commonjs`
  });

  // React-land is rather undertyped; nontrivial TS projects will most likely
  // error (i.e., not build) at something or other.
  var opts = { compilerOptions: copts, transpileOnly: true

    // Load gatsby babel plugin to extract graphql query
  };var extractQueryPlugin = path.resolve(__dirname, `../gatsby/dist/utils/babel-plugin-extract-graphql.js`);

  config.loader(`typescript`, {
    test,
    loaders: [`babel?${JSON.stringify({ plugins: [extractQueryPlugin] })}`, `ts-loader?${JSON.stringify(opts)}`]
  });
};

module.exports.preprocessSource = function (_ref3, _ref4) {
  var contents = _ref3.contents,
      filename = _ref3.filename;
  var compilerOptions = _ref4.compilerOptions;

  // overwrite defaults with custom compiler options
  var copts = Object.assign({}, compilerDefaults, compilerOptions, {
    target: `esnext`,
    module: `es6`
  });
  // return the transpiled source if it's TypeScript, otherwise null
  return test.test(filename) ? transpileModule(contents, { compilerOptions: copts }).outputText : null;
};

==> gatsby-plugin-typescript-1.4.9.tgz: package/gatsby-node.js <==
"use strict";

var _require = require(`typescript`),
    transpileModule = _require.transpileModule;

var path = require(`path`);

var test = /\.tsx?$/;
var compilerDefaults = {
  target: `esnext`,
  experimentalDecorators: true,
  jsx: `react`
};

module.exports.resolvableExtensions = function () {
  return [`.ts`, `.tsx`];
};

module.exports.modifyWebpackConfig = function (_ref, _ref2) {
  var config = _ref.config;
  var compilerOptions = _ref2.compilerOptions,
      _ref2$transpileOnly = _ref2.transpileOnly,
      transpileOnly = _ref2$transpileOnly === undefined ? true : _ref2$transpileOnly;

  // CommonJS to keep Webpack happy.
  var copts = Object.assign({}, compilerDefaults, compilerOptions, {
    module: `commonjs`
  });

  // React-land is rather undertyped; nontrivial TS projects will most likely
  // error (i.e., not build) at something or other.
  var opts = { compilerOptions: copts, transpileOnly

    // Load gatsby babel plugin to extract graphql query
  };var extractQueryPlugin = path.resolve(__dirname, `../gatsby/dist/utils/babel-plugin-extract-graphql.js`);

  config.loader(`typescript`, {
    test,
    loaders: [`babel?${JSON.stringify({ plugins: [extractQueryPlugin] })}`, `ts-loader?${JSON.stringify(opts)}`]
  });
};

module.exports.preprocessSource = function (_ref3, _ref4) {
  var contents = _ref3.contents,
      filename = _ref3.filename;
  var compilerOptions = _ref4.compilerOptions;

  // overwrite defaults with custom compiler options
  var copts = Object.assign({}, compilerDefaults, compilerOptions, {
    target: `esnext`,
    module: `es6`
  });
  // return the transpiled source if it's TypeScript, otherwise null
  return test.test(filename) ? transpileModule(contents, { compilerOptions: copts }).outputText : null;
};
